@@ -5,15 +5,18 @@
 # A simple method for displaying the hydropathic character of a protein.
 # Journal of Molecular Biology, 157(1), 105-32.
 
-hydrophobicity<-function(seq,scale="KyteDoolittle"){
-  seq<-gsub("[\r\n ]","",seq)
+hydrophobicity <- function(seq, scale = "KyteDoolittle") {
+  seq <- gsub("[[:space:]]", "", seq)
   # Loading hydrophobicity scales
   data(H, envir = environment())
-  H<-H
+  H <- H
   # Setting the hydrophobicity scale
-  M<-names(H)
-  scale<-match.arg(scale,M)
+  scale <- match.arg(scale, names(H))
   # Sum the hydrophobicity of each amino acid and divide them between the sequence length
   # Return the GRAVY value
-  sum(H[[scale]][strsplit(seq,"")[[1]]],na.rm = TRUE)/nchar(seq)
+  h <-
+    lapply(seq, function(seq) {
+      (sum(H[[scale]][unlist(strsplit(seq, ""))], na.rm = TRUE) / nchar(seq))
+    })
+  return(unlist(h))
 }
