@@ -4,14 +4,20 @@
 # Statistical analysis of the physical properties of the 20 naturally occurring amino acids.
 # Journal of Protein Chemistry, 4(1), 23-55.
 
-kidera <- function (seq, factor=""){
+kidera <- function (seq) {
   # Remove the break lines from the sequence
-  seq <- gsub("[\r\n ]", "", seq)
+  seq <- gsub("[[:space:]]", "", seq)
   # Load the KFactors data
   data(Kfactors, envir = environment())
   Kfactors <- Kfactors
-  # Stablish the factor to use.
-  factor<-match.arg(factor,names(Kfactors))
   # Compute the selected Kidera factor.
-  sum(Kfactors[[factor]][strsplit(seq, "")[[1]]], na.rm = TRUE)/nchar(seq)
+  seq <- lapply(seq, function(seq) {
+    unlist(strsplit(seq, ""))
+  })
+  kf <- lapply(seq, function(seq) {
+    sapply(names(Kfactors), function(factor) {
+      sum(Kfactors[[factor]][seq], na.rm = TRUE) / length(seq)
+    })
+  })
+  return(kf)
 }
