@@ -5,7 +5,7 @@ test.pI<- function(){
   # Theoretical pI: 9.88
   
   # CHECK pI VALUE
-  checkEquals(pI("QWGRRCCGWGPGRRYCVRWC","Bjellqvist"),9.88,tolerance = 0.01)
+  checkEquals(pI(seq = "QWGRRCCGWGPGRRYCVRWC",pKscale = "Bjellqvist"),9.88,tolerance = 0.01)
   
   # CHECK OUTPUT CLASS
   checkTrue(is.numeric(pI("QWGRRCCGWGPGRRYCVRWC","Bjellqvist")))
